@@ -16,7 +16,6 @@
 #include "StOpt/core/parallelism/ParallelComputeGridSplitting.h"
 #include "StOpt/core/grids/GridIterator.h"
 #include "StOpt/core/utils/eigenGeners.h"
-#include "StOpt/regression/ContinuationValueDet.h"
 #include "StOpt/regression/ContinuationValue.h"
 #include "StOpt/regression/ContinuationValueGeners.h"
 #include "StOpt/regression/GridAndRegressedValue.h"
@@ -99,20 +98,11 @@ void TransitionStepMultiStageRegressionDPDist::oneStageInStep(const vector< shar
     if (m_gridCurrentProc->getNbPoints() > 0)
     {
         //  create continuation values on extended grid
-        vector<shared_ptr<ContinuationValueBase> > contVal(p_phiIn.size());
-        // test if  deterministic of stochastic
-        if (p_pGridPrevTransExtended == m_gridExtendPreviousStep)
-        {
-            // stochastic
-            for (size_t iReg = 0; iReg < p_phiIn.size(); ++iReg)
-                contVal[iReg] = make_shared<ContinuationValue>(p_pGridPrevTransExtended, p_condExp, *phiInExtended[iReg]);
-        }
-        else
-        {
-            // stochastic
-            for (size_t iReg = 0; iReg < p_phiIn.size(); ++iReg)
-                contVal[iReg] = make_shared<ContinuationValueDet>(p_pGridPrevTransExtended, *phiInExtended[iReg]);
-        }
+        vector<shared_ptr<ContinuationValue> > contVal(p_phiIn.size());
+	// stochastic
+	for (size_t iReg = 0; iReg < p_phiIn.size(); ++iReg)
+	  contVal[iReg] = make_shared<ContinuationValue>(p_pGridPrevTransExtended, p_condExp, *phiInExtended[iReg]);
+
 
         // number of thread
 #ifdef _OPENMP
