@@ -77,7 +77,7 @@ BOOST_AUTO_TEST_CASE(testParallelism1D)
     // splitting for process
     ArrayXi splittingRatio(1);
     splittingRatio(0) = world.size();
-    ParallelComputeGridSplitting paral(initialDimension, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, splittingRatio, world);
     // local grid
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocal = paral.getCurrentCalculationGrid();
     int iSizeLoc = gridLocal(0)[1] - gridLocal(0)[0];
@@ -141,7 +141,7 @@ BOOST_AUTO_TEST_CASE(testParallelism1DOneD)
     // splitting for process
     ArrayXi splittingRatio(1);
     splittingRatio(0) = world.size();
-    ParallelComputeGridSplitting paral(initialDimension, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, splittingRatio, world);
     // local grid
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocal = paral.getCurrentCalculationGrid();
     int iSizeLoc = gridLocal(0)[1] - gridLocal(0)[0];
@@ -200,7 +200,7 @@ BOOST_AUTO_TEST_CASE(testParallelism2D)
     {
         splittingRatio(i % 2) *= prime[i] ;
     }
-    ParallelComputeGridSplitting paral(initialDimension, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, splittingRatio, world);
     // local grid
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocal = paral.getCurrentCalculationGrid();
     int iSizeLoc1 = (gridLocal(0)[1] - gridLocal(0)[0]);
@@ -280,7 +280,7 @@ BOOST_AUTO_TEST_CASE(testParallelism2DOneDArray)
     {
         splittingRatio(i % 2) *= prime[i] ;
     }
-    ParallelComputeGridSplitting paral(initialDimension, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, splittingRatio, world);
     // local grid
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocal = paral.getCurrentCalculationGrid();
     int iSizeLoc1 = (gridLocal(0)[1] - gridLocal(0)[0]);
@@ -351,7 +351,7 @@ BOOST_AUTO_TEST_CASE(testParallelism3D)
     {
         splittingRatio(i % 3) *= prime[i] ;
     }
-    ParallelComputeGridSplitting paral(initialDimension, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, splittingRatio, world);
     // local grid
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocal = paral.getCurrentCalculationGrid();
     int iSizeLoc1 = (gridLocal(0)[1] - gridLocal(0)[0]);
@@ -453,7 +453,7 @@ BOOST_AUTO_TEST_CASE(testParallelism4D)
     {
         splittingRatio(i % 4) *= prime[i] ;
     }
-    ParallelComputeGridSplitting paral(initialDimension, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, splittingRatio, world);
     // local grid
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocal = paral.getCurrentCalculationGrid();
     int iSizeLoc1 = (gridLocal(0)[1] - gridLocal(0)[0]);
@@ -561,7 +561,7 @@ BOOST_AUTO_TEST_CASE(testParallelismWithCone1D)
     // splitting for process
     ArrayXi splittingRatio(1);
     splittingRatio(0) = world.size();
-    ParallelComputeGridSplitting paral(initialDimension, fMesh, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, fMesh, splittingRatio, world);
     // local grid
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocal = paral.getCurrentCalculationGrid();
     int iSizeLoc = gridLocal(0)[1] - gridLocal(0)[0];
@@ -606,7 +606,7 @@ BOOST_AUTO_TEST_CASE(testParallelismWithCone2D)
     {
         splittingRatio(i % 2) *= prime[i] ;
     }
-    ParallelComputeGridSplitting paral(initialDimension, fMesh, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, fMesh, splittingRatio, world);
     // local grid
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocal = paral.getCurrentCalculationGrid();
     int iSizeLoc1 = (gridLocal(0)[1] - gridLocal(0)[0]);
@@ -656,7 +656,7 @@ BOOST_AUTO_TEST_CASE(testParallelismWithCone3D)
     {
         splittingRatio(i % 3) *= prime[i] ;
     }
-    ParallelComputeGridSplitting paral(initialDimension, fMesh, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, fMesh, splittingRatio, world);
     // local grid
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocal = paral.getCurrentCalculationGrid();
     int iSizeLoc1 = (gridLocal(0)[1] - gridLocal(0)[0]);
@@ -711,7 +711,7 @@ BOOST_AUTO_TEST_CASE(testParallelismWithConeAndVaryingMesh1D)
     // splitting for process
     ArrayXi splittingRatio(1);
     splittingRatio(0) = world.size();
-    ParallelComputeGridSplitting paral(initialDimension, initialDimensionPrev, fMesh, splittingRatio, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, initialDimensionPrev, fMesh, splittingRatio, splittingRatio, world);
     // grid at previous step
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocalPrev = paral.getPreviousCalculationGrid();
 
@@ -759,7 +759,7 @@ BOOST_AUTO_TEST_CASE(testParallelismWithConeAndVaryingMesh2D)
     {
         splittingRatio(i % 2) *= prime[i] ;
     }
-    ParallelComputeGridSplitting paral(initialDimension, initialDimensionPrev, fMesh, splittingRatio, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, initialDimensionPrev, fMesh, splittingRatio, splittingRatio, world);
     // grid at previous step
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocalPrev = paral.getPreviousCalculationGrid();
     int iSizeLoc1 = (gridLocalPrev(0)[1] - gridLocalPrev(0)[0]);
@@ -813,7 +813,7 @@ BOOST_AUTO_TEST_CASE(testParallelismWithConeAndVaryingMesh3D)
     {
         splittingRatio(i % 3) *= prime[i] ;
     }
-    ParallelComputeGridSplitting paral(initialDimension, initialDimensionPrev, fMesh, splittingRatio, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, initialDimensionPrev, fMesh, splittingRatio, splittingRatio, world);
     // grid at previous step
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocalPrev = paral.getPreviousCalculationGrid();
     int iSizeLoc1 = (gridLocalPrev(0)[1] - gridLocalPrev(0)[0]);
@@ -877,7 +877,7 @@ BOOST_AUTO_TEST_CASE(testParallelismWithConeAndVaryingMesh4D)
     {
         splittingRatio(i % 4) *= prime[i] ;
     }
-    ParallelComputeGridSplitting paral(initialDimension, initialDimensionPrev, fMesh, splittingRatio, splittingRatio);
+    ParallelComputeGridSplitting paral(initialDimension, initialDimensionPrev, fMesh, splittingRatio, splittingRatio, world);
     // grid at previous step
     Eigen::Array<  array<int, 2 >, Eigen::Dynamic, 1 > gridLocalPrev = paral.getPreviousCalculationGrid();
     int iSizeLoc1 = (gridLocalPrev(0)[1] - gridLocalPrev(0)[0]);
